use std::io::Cursor;

use axum::{routing::get, Router};
use axum_extra::{headers::Range, TypedHeader};
use axum_range::{KnownSize, Ranged};

use super::Context;

const HTMX: &str = include_str!("./htmx_2.0.4.min.js");
const PICOCSS: &str = include_str!("./pico_2.1.1.classless.jade.min.css");

type RangedResponse = Ranged<KnownSize<Cursor<&'static str>>>;

pub fn router() -> Router<Context> {
    Router::new()
        .route("/htmx_2.0.4.min.js", get(get_htmx))
        .route("/pico_2.1.1.classless.jade.min.css", get(get_picocss))
}

#[inline(always)]
fn serve_static(data: &'static str, range: Option<Range>) -> RangedResponse {
    let cursor = Cursor::new(data);
    let body = KnownSize::sized(cursor, data.len() as u64);

    Ranged::new(range, body)
}

async fn get_htmx(range: Option<TypedHeader<Range>>) -> RangedResponse {
    serve_static(HTMX, range.map(|TypedHeader(range)| range))
}

async fn get_picocss(range: Option<TypedHeader<Range>>) -> RangedResponse {
    serve_static(PICOCSS, range.map(|TypedHeader(range)| range))
}
